ENABLED_W

Type Alias ENABLED_W 

pub type ENABLED_W<'a, REG, const O: u8> = BitWriter<'a, REG, O, ENABLED_A>;
Field enabled writer - UART enabled, to enable UART block, it is used to drive a gated clock in order to save power consumption when UART is not used.

Aliased Type

pub struct ENABLED_W<'a, REG, const O: u8> { /* private fields */ }

Implementations

Source

impl<'a, REG, const O: u8> ENABLED_W<'a, REG, O>
where REG: Writable + RegisterSpec,

pub fn disabled(self) -> &'a mut W<REG>

UART disabled.

pub fn enabled(self) -> &'a mut W<REG>

UART enabled.