W

Type Alias W 

pub type W = W<CTRL0_SPEC>;
Register CTRL0 writer

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn enabled(&mut self) -> ENABLED_W<'_, CTRL0_SPEC, 0>

Bit 0 - UART enabled, to enable UART block, it is used to drive a gated clock in order to save power consumption when UART is not used.

pub fn parity_en(&mut self) -> PARITY_EN_W<'_, CTRL0_SPEC, 1>

Bit 1 - Enable/disable Parity bit (9th character).

pub fn parity_mode(&mut self) -> PARITY_MODE_W<'_, CTRL0_SPEC, 2>

Bits 2:3 - When PARITY_EN=1, selects odd, even, Mark or Space parity.

pub fn parity_lvl(&mut self) -> PARITY_LVL_W<'_, CTRL0_SPEC, 4>

Bit 4 - Selects parity based on 1s or 0s count (when PARITY_EN=1).

pub fn txflush(&mut self) -> TXFLUSH_W<'_, CTRL0_SPEC, 5>

Bit 5 - Flushes the TX FIFO buffer.

pub fn rxflush(&mut self) -> RXFLUSH_W<'_, CTRL0_SPEC, 6>

Bit 6 - Flushes the RX FIFO buffer.

pub fn bitacc(&mut self) -> BITACC_W<'_, CTRL0_SPEC, 7>

Bit 7 - Bit accuracy selection.

pub fn size(&mut self) -> SIZE_W<'_, CTRL0_SPEC, 8>

Bits 8:9 - Selects UART character size.

pub fn stop(&mut self) -> STOP_W<'_, CTRL0_SPEC, 10>

Bit 10 - Selects the number of stop bits that will be generated.

pub fn flow(&mut self) -> FLOW_W<'_, CTRL0_SPEC, 11>

Bit 11 - Enables/disables hardware flow control.

pub fn flowpol(&mut self) -> FLOWPOL_W<'_, CTRL0_SPEC, 12>

Bit 12 - RTS/CTS polarity.

pub fn nullmod(&mut self) -> NULLMOD_W<'_, CTRL0_SPEC, 13>

Bit 13 - NULL Modem Support (RTS/CTS and TXD/RXD swap).

pub fn break_(&mut self) -> BREAK_W<'_, CTRL0_SPEC, 14>

Bit 14 - Break control bit.

pub fn clk_sel(&mut self) -> CLK_SEL_W<'_, CTRL0_SPEC, 15>

Bit 15 - Baud Rate Clock Source Select.

pub fn to_cnt(&mut self) -> TO_CNT_W<'_, CTRL0_SPEC, 16>

Bits 16:23 - RX Time Out.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Safety

Passing incorrect value can cause undefined behaviour. See reference manual