R

Type Alias R 

pub type R = R<INT_FL_SPEC>;
Register INT_FL reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn frame(&self) -> FRAME_R

Bit 0 - FLAG for RX Frame Error Interrupt.

pub fn parity(&self) -> PARITY_R

Bit 1 - FLAG for RX Parity Error interrupt.

pub fn cts(&self) -> CTS_R

Bit 2 - FLAG for CTS signal change interrupt.

pub fn rx_ovr(&self) -> RX_OVR_R

Bit 3 - FLAG for RX FIFO Overrun interrupt.

pub fn rx_fifo_lvl(&self) -> RX_FIFO_LVL_R

Bit 4 - FLAG for interrupt when RX FIFO reaches the number of bytes configured by the RXTHD field.

pub fn tx_fifo_ae(&self) -> TX_FIFO_AE_R

Bit 5 - FLAG for interrupt when TX FIFO has only one byte remaining.

pub fn tx_fifo_lvl(&self) -> TX_FIFO_LVL_R

Bit 6 - FLAG for interrupt when TX FIFO reaches the number of bytes configured by the TXTHD field.

pub fn break_(&self) -> BREAK_R

Bit 7 - FLAG for received BREAK character interrupt.

pub fn rx_to(&self) -> RX_TO_R

Bit 8 - FLAG for RX Timeout Interrupt.

pub fn last_break(&self) -> LAST_BREAK_R

Bit 9 - FLAG for Last break character interrupt.