R

Type Alias R 

pub type R = R<STAT_SPEC>;
Register STAT reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn tx_busy(&self) -> TX_BUSY_R

Bit 0 - Read-only flag indicating the UART transmit status.

pub fn rx_busy(&self) -> RX_BUSY_R

Bit 1 - Read-only flag indicating the UARTreceiver status.

pub fn parity(&self) -> PARITY_R

Bit 2 - 9th Received bit state.

pub fn break_(&self) -> BREAK_R

Bit 3 - Received BREAK status.

pub fn rx_empty(&self) -> RX_EMPTY_R

Bit 4 - Read-only flag indicating the RX FIFO state.

pub fn rx_full(&self) -> RX_FULL_R

Bit 5 - Read-only flag indicating the RX FIFO state.

pub fn tx_empty(&self) -> TX_EMPTY_R

Bit 6 - Read-only flag indicating the TX FIFO state.

pub fn tx_full(&self) -> TX_FULL_R

Bit 7 - Read-only flag indicating the TX FIFO state.

pub fn rx_num(&self) -> RX_NUM_R

Bits 8:13 - Indicates the number of bytes currently in the RX FIFO.

pub fn tx_num(&self) -> TX_NUM_R

Bits 16:21 - Indicates the number of bytes currently in the TX FIFO.

pub fn rx_to(&self) -> RX_TO_R

Bit 24 - RX Timeout status.