pub type ENABLED_W<'a, REG, const O: u8> = BitWriter<'a, REG, O, ENABLED_A>;Expand description
Field enabled writer - UART enabled, to enable UART block, it is used to drive a gated clock in order to save power consumption when UART is not used.
Aliased Type
pub struct ENABLED_W<'a, REG, const O: u8> { /* private fields */ }