pub type W = W<CTRL0_SPEC>;Expand description
Register CTRL0 writer
Aliased Type
pub struct W { /* private fields */ }Implementations
Sourceimpl W
impl W
Sourcepub fn enabled(&mut self) -> ENABLED_W<'_, CTRL0_SPEC, 0>
pub fn enabled(&mut self) -> ENABLED_W<'_, CTRL0_SPEC, 0>
Bit 0 - UART enabled, to enable UART block, it is used to drive a gated clock in order to save power consumption when UART is not used.
Sourcepub fn parity_en(&mut self) -> PARITY_EN_W<'_, CTRL0_SPEC, 1>
pub fn parity_en(&mut self) -> PARITY_EN_W<'_, CTRL0_SPEC, 1>
Bit 1 - Enable/disable Parity bit (9th character).
Sourcepub fn parity_mode(&mut self) -> PARITY_MODE_W<'_, CTRL0_SPEC, 2>
pub fn parity_mode(&mut self) -> PARITY_MODE_W<'_, CTRL0_SPEC, 2>
Bits 2:3 - When PARITY_EN=1, selects odd, even, Mark or Space parity.
Sourcepub fn parity_lvl(&mut self) -> PARITY_LVL_W<'_, CTRL0_SPEC, 4>
pub fn parity_lvl(&mut self) -> PARITY_LVL_W<'_, CTRL0_SPEC, 4>
Bit 4 - Selects parity based on 1s or 0s count (when PARITY_EN=1).
Sourcepub fn txflush(&mut self) -> TXFLUSH_W<'_, CTRL0_SPEC, 5>
pub fn txflush(&mut self) -> TXFLUSH_W<'_, CTRL0_SPEC, 5>
Bit 5 - Flushes the TX FIFO buffer.
Sourcepub fn rxflush(&mut self) -> RXFLUSH_W<'_, CTRL0_SPEC, 6>
pub fn rxflush(&mut self) -> RXFLUSH_W<'_, CTRL0_SPEC, 6>
Bit 6 - Flushes the RX FIFO buffer.
Sourcepub fn bitacc(&mut self) -> BITACC_W<'_, CTRL0_SPEC, 7>
pub fn bitacc(&mut self) -> BITACC_W<'_, CTRL0_SPEC, 7>
Bit 7 - Bit accuracy selection.
Sourcepub fn size(&mut self) -> SIZE_W<'_, CTRL0_SPEC, 8>
pub fn size(&mut self) -> SIZE_W<'_, CTRL0_SPEC, 8>
Bits 8:9 - Selects UART character size.
Sourcepub fn stop(&mut self) -> STOP_W<'_, CTRL0_SPEC, 10>
pub fn stop(&mut self) -> STOP_W<'_, CTRL0_SPEC, 10>
Bit 10 - Selects the number of stop bits that will be generated.
Sourcepub fn flow(&mut self) -> FLOW_W<'_, CTRL0_SPEC, 11>
pub fn flow(&mut self) -> FLOW_W<'_, CTRL0_SPEC, 11>
Bit 11 - Enables/disables hardware flow control.
Sourcepub fn flowpol(&mut self) -> FLOWPOL_W<'_, CTRL0_SPEC, 12>
pub fn flowpol(&mut self) -> FLOWPOL_W<'_, CTRL0_SPEC, 12>
Bit 12 - RTS/CTS polarity.
Sourcepub fn nullmod(&mut self) -> NULLMOD_W<'_, CTRL0_SPEC, 13>
pub fn nullmod(&mut self) -> NULLMOD_W<'_, CTRL0_SPEC, 13>
Bit 13 - NULL Modem Support (RTS/CTS and TXD/RXD swap).
Sourcepub fn break_(&mut self) -> BREAK_W<'_, CTRL0_SPEC, 14>
pub fn break_(&mut self) -> BREAK_W<'_, CTRL0_SPEC, 14>
Bit 14 - Break control bit.
Sourcepub fn clk_sel(&mut self) -> CLK_SEL_W<'_, CTRL0_SPEC, 15>
pub fn clk_sel(&mut self) -> CLK_SEL_W<'_, CTRL0_SPEC, 15>
Bit 15 - Baud Rate Clock Source Select.
Sourcepub fn to_cnt(&mut self) -> TO_CNT_W<'_, CTRL0_SPEC, 16>
pub fn to_cnt(&mut self) -> TO_CNT_W<'_, CTRL0_SPEC, 16>
Bits 16:23 - RX Time Out.