pub type R = R<INT_FL_SPEC>;Expand description
Register INT_FL reader
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn rx_fifo_lvl(&self) -> RX_FIFO_LVL_R
pub fn rx_fifo_lvl(&self) -> RX_FIFO_LVL_R
Bit 4 - FLAG for interrupt when RX FIFO reaches the number of bytes configured by the RXTHD field.
Sourcepub fn tx_fifo_ae(&self) -> TX_FIFO_AE_R
pub fn tx_fifo_ae(&self) -> TX_FIFO_AE_R
Bit 5 - FLAG for interrupt when TX FIFO has only one byte remaining.
Sourcepub fn tx_fifo_lvl(&self) -> TX_FIFO_LVL_R
pub fn tx_fifo_lvl(&self) -> TX_FIFO_LVL_R
Bit 6 - FLAG for interrupt when TX FIFO reaches the number of bytes configured by the TXTHD field.
Sourcepub fn last_break(&self) -> LAST_BREAK_R
pub fn last_break(&self) -> LAST_BREAK_R
Bit 9 - FLAG for Last break character interrupt.